package vn.vccorp.msh_mesg_tracking_v2;

import android.content.Context;
import android.util.Log;

import androidx.annotation.NonNull;


import com.mesglog.sdk.ParamsLog;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

public class MessLogV2Plugin implements FlutterPlugin, MethodCallHandler {
  public static final String TAG = MessLogV2Plugin.class.getName();
  private MethodChannel channel;
  private Context context;
  private MessLogV2Native messLogV2Native;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "mess_log_tracking_v2");
    channel.setMethodCallHandler(this);
    this.context = flutterPluginBinding.getApplicationContext();
    messLogV2Native = new MessLogV2Native();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    switch (call.method){
      case "getLibVersion":
        result.success(MessLogV2Native.getVersionLibVersion());
        break;
      case "getDeviceId":
        if(context != null){
          result.success(MessLogV2Native.getUniquePsuedoID(context));
        }
        break;
      case "sendLogInstall":
        if(context != null){
          String message = call.argument("ext");
          result.success(messLogV2Native.sendLogInstall(context, message));
        }
        break;
      case "sendLogConfirm":
        if(context != null){
          String message = call.argument("ext");
          result.success(messLogV2Native.sendLogConfirm(context, message));
        }
        break;
      case "sendLogAction":
        Log.d(TAG, "sendLogAction");
        if(context != null){
          String isClose = call.argument("is_close");
          String ext = call.argument("ext");
          result.success(messLogV2Native.sendLogAction(context, isClose, ext));
        }
        break;
      case "sendLogTrackingView":
        if(context != null){
          String domain = call.argument("domain");
          String curl = call.argument("curl");
          String rurl = call.argument("rurl");
          String vid = call.argument("vid");
          String cov = call.argument("cov");
          String ltype = call.argument("ltype");
          String boxid = call.argument("boxid");
          String dspid = call.argument("dspid");
          String algid = call.argument("algid");
          String ext = call.argument("ext");
          result.success(messLogV2Native.sendLogTrackingView(context, domain, curl, rurl, vid, cov, ltype, boxid, dspid, algid, ext));
        }
        break;
      case "sendLogClickBanner":
        if(context != null){
          String appId = call.argument("app_id");
          String currentActivity = call.argument("current_activity");
          String currentAction = call.argument("current_action");
          String ext = call.argument("ext");
          result.success(messLogV2Native.sendLogClickBanner(context, appId, currentActivity, currentAction, ext));
        }
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
