import 'package:msh_mesg_tracking_v2/src/exception/mess_log_tracking_v2_exception.dart';
import 'mess_log_v2_native.dart';
import 'model/model.dart';
import 'dart:io' show Platform;


/// MessLogTrackingV2
class MessLogTrackingV2{
  MessLogV2Native _messLogV2Native;

  MessLogTrackingV2 initialized(){
    if(_messLogV2Native == null){
      _messLogV2Native = MessLogV2Native();
    }
    return this;
  }

  /// handleAppOpen
  /// Process event when app open or setting
  Future<void> handleAppOpen() async{
    if (Platform.isIOS) {
      await _messLogV2Native.handleAppOpen();
    }else if(Platform.isAndroid){
      // send log install open first time app
      // send log open or install
      await _messLogV2Native.sendLogInstall("");
      await _messLogV2Native.sendLogAction("0", "");
    }else{
      print("method handleAppOpen not support your platform!");
    }
  }
  
  /// handleAppQuit
  /// Process event when app has quit
  Future<bool> handleAppQuit() async{
    if (Platform.isIOS) { // do nothing
      return await _messLogV2Native.handleAppQuit();
    }else if(Platform.isAndroid){
      return _messLogV2Native.sendLogAction("1", "");
    }
    throw MessLogV2TRackingV2Exception(
        "Method handleAppQuit not support current platform !");
  }

  /// handleAppEnterForeground
  /// Process event when app runing
  Future<bool> handleAppEnterForeground() async{
    if (Platform.isIOS) {
      return await _messLogV2Native.handleAppEnterForeground();
    }else if(Platform.isAndroid){
      return true;
    }
    throw MessLogV2TRackingV2Exception(
        "Method handleAppEnterForeground not support current platform !");
  }

  /// handleAppWillTerminate
  /// Process event when app running
  Future<bool> handleAppWillTerminate() async{
    if (Platform.isIOS) {
      return await _messLogV2Native.handleAppWillTerminate();
    }else if(Platform.isAndroid){
      return true;
    }
    throw MessLogV2TRackingV2Exception(
        "Method handleAppWillTerminate not support current platform !");
  }

  /// getLibVersion
  /// Method will return lib version
  Future<String> get getLibVersion async{
    return await _messLogV2Native.getLibVersion;
  }

  /// getUUID
  /// Method will return device ID
  Future<String> get getUUID async{
    return await _messLogV2Native.getUUID;
  }

  /// sendLogInstall
  /// Send log when install app
  // Future<bool> sendLogInstall(String ext) async{
  //   return await _messLogV2Native.sendLogInstall(ext);
  //   throw MessLogV2TRackingV2Exception("Method sendLogInstall not support platform !");
  // }

  Future<bool> sendLogAction(String isClose, String ext) async{
    if(Platform.isAndroid || Platform.isIOS){
      return await _messLogV2Native.sendLogAction(isClose, ext);
    }
    throw MessLogV2TRackingV2Exception("sendLogAction ot support platform !");
  }

  Future<bool> sendLogConfirm(String ext) async{
    return await _messLogV2Native.sendLogConfirm(ext);
  }

  /// sendLogTrackingView
  /// This method use to tracking Ads
  Future<bool> sendLogTrackingView(String domain, String curl, String rurl,
    String vid, COV_TYPE cov, LOG_TYPE ltype, String boxid, String dspid, String algid, String ext) async{

    if(Platform.isAndroid || Platform.isIOS){
       String nCov = "0";
    switch(cov){
      case COV_TYPE.VIEW:
        nCov = "0";
        break;
      case COV_TYPE.CLICK:
        nCov = "1";
        break;
      case COV_TYPE.SCROLL:
        nCov = "2";
        break;
    }
    String nltype = "0";
    switch(ltype){
      case LOG_TYPE.NONE:
        nltype = "0";
        break;
      case LOG_TYPE.PAGE_VIEW:
        nltype = "1";
        break;
      case LOG_TYPE.RECV:
        nltype = "2";
        break;
      case LOG_TYPE.BOX_VIEW:
        nltype = "3";
        break;
    }
      return await _messLogV2Native.sendLogTrackingView(domain, curl, rurl, vid, nCov, nltype,
          dspid, boxid, algid, ext);
    }
    throw MessLogV2TRackingV2Exception("Method sendLogTrackingView not support platform !");
  }


  /// sendLogClickBanner
  /// This method use to tracking click ads in apps.
  /// Each one ads will be given one app_id. When click to ads.
  /// Need parameter activity present: package + activity Ex: vcc.soha.game.DetailsScreen currentAction: click(“0”) or view (“1”)
  Future<bool> sendLogClickBanner(String appId, String currentActivity, String currentAction, String ext) async{
    if(Platform.isAndroid || Platform.isIOS){
      return await _messLogV2Native.sendLogClickBanner(appId, currentActivity, currentAction, ext);
    }
    throw MessLogV2TRackingV2Exception("Method sendLogClickBanner not support platform !");
  }


  /// sendLogTrackingViewWithParams
  /// This method use to tracking Ads
  /// require @link ParamsLog
  Future<bool> sendLogTrackingViewLogParams(ParamsLog paramsLog) async{
    if(Platform.isAndroid || Platform.isIOS){
      return await _messLogV2Native.sendLogTrackingViewParamLog(paramsLog);
    }

    throw MessLogV2TRackingV2Exception("Method sendLogTrackingViewWithParams not support platform !");
  }
}