import 'dart:async';
import 'package:flutter/services.dart';
import 'dart:io' show Platform;
import 'exception/mess_log_tracking_v2_exception.dart';
import 'model/model.dart';

class MessLogV2Native {
  static MethodChannel channel = const MethodChannel('mess_log_tracking_v2');

  /// Invoke method channel handleAppOpen native
  Future<void> handleAppOpen() async {
    if(Platform.isIOS){
      await channel.invokeMethod('handleAppOpen');
    }else if(Platform.isAndroid){
      await channel.invokeMethod('handleAppOpen');
    }
  }
  /// Invoke method channel handleAppQuit native
  Future<bool> handleAppQuit() async {
    var rs = await channel.invokeMethod('handleAppQuit');
    return rs == 1;
  }

  /// Invoke method channel handleAppEnterForeground native
  Future<bool> handleAppEnterForeground() async {
    if(Platform.isIOS){
      var rs = await channel.invokeMethod('handleAppEnterForeground');
      return rs == 1;
    }
    throw MessLogV2TRackingV2Exception(
        "Method handleAppEnterForeground not support current platform !");
  }

  /// Invoke method channel handleAppWillTerminate native
  Future<bool> handleAppWillTerminate() async {
    if (Platform.isIOS) {
      var rs = await channel.invokeMethod('handleAppWillTerminate');
      return rs == 1;
    }
    throw MessLogV2TRackingV2Exception(
        "Method handleAppWillTerminate not support current platform !");
  }

  /// Invoke method channel applicationWillTerminate native
  Future<bool> applicationWillTerminate() async {
    if (Platform.isIOS) {
      var rs = await channel.invokeMethod('applicationWillTerminate');
      return rs == 1;
    }else if(Platform.isAndroid){
      return true;
    }
    throw MessLogV2TRackingV2Exception(
        "Method applicationWillTerminate not support current platform !");
  }

  /// Invoke method channel getLibVersion native
  Future<String> get getLibVersion async {
    String version = "Unknown version";
    final String result = await channel.invokeMethod('getLibVersion');
    if (result != null && result.isNotEmpty) {
      version = result;
    }
    return version;
  }

  /// Invoke method channel getUUID native
  Future<String> get getUUID async {
    String uuid = "Unknown version";
    final String result = await channel.invokeMethod('getDeviceId');
    if (result != null && result.isNotEmpty) {
      uuid = result;
    }
    return uuid;
  }

  /// Invoke method channel sendLogInstall native
  Future<bool> sendLogInstall(String ext) async {
    if (Platform.isAndroid) {
      bool response = false;
      final bool result =
          await channel.invokeMethod('sendLogInstall', {'ext': ext});
      if (result != null) {
        response = result;
      }
      return response;
    }
    if (Platform.isIOS) {
      return await channel.invokeMethod('sendLogInstall', {'ext': ext});
    }
    throw MessLogV2TRackingV2Exception("sendLogConfirm not support platform !");
  }

  /// Invoke method channel sendLogConfirm native
  Future<bool> sendLogConfirm(String ext) async {
    if (Platform.isAndroid) {
      bool response = false;
      final bool result =
          await channel.invokeMethod('sendLogConfirm', {'ext': ext});
      if (result != null) {
        response = result;
      }
      return response;
    } else if (Platform.isIOS) {
      var rs = await channel.invokeMethod('sendLogConfirm', {'ext': ext});
      return rs == 1;
    }
    throw MessLogV2TRackingV2Exception("sendLogConfirm not support platform !");
  }

  /// Invoke method channel sendLogAction native
  Future<bool> sendLogAction(String isClose, String ext) async {
    return await channel
          .invokeMethod('sendLogAction', {'is_close': isClose, 'ext': ext});
  }

  /// Invoke method channel sendLogTrackingView native
  Future<bool> sendLogTrackingView(String domain, String curl, rurl, vid, cov,
      ltype, boxid, dspid, algid, ext) async {
    if (Platform.isAndroid) {
      return await channel.invokeMethod('sendLogTrackingView', {
        'domain': domain,
        'curl': curl,
        'rurl': rurl,
        'vid': vid,
        'cov': cov,
        'ltype': ltype,
        'boxid': boxid,
        'dspid': dspid,
        'algid': algid,
        'ext': ext
      });
    }else if(Platform.isIOS){
      var rs = await channel.invokeMethod('sendLogTrackingView', {
        'domain': domain,
        'curl': curl,
        'rurl': rurl,
        'vid': vid,
        'cov': cov,
        'ltype': ltype,
        'boxid': boxid,
        'dspid': dspid,
        'algid': algid,
        'ext': ext
      });
      return rs == 1;
    }
    throw MessLogV2TRackingV2Exception(
        "Method sendLogTrackingView not support platform !");
  }

  /// Invoke method channel sendLogClickBanner native
  Future<bool> sendLogClickBanner(String appId, String currentActivity,
      String currentAction, String ext) async {
    if (Platform.isAndroid) {
      bool response = false;
      final bool result = await channel.invokeMethod('sendLogAction', {
        'app_id': appId,
        'current_activity': currentActivity,
        'current_action': currentAction,
        'ext': ext
      });
      if (result != null) {
        response = result;
      }
      return response;
    } else if (Platform.isIOS) {
      var result = await channel.invokeMethod('sendLogClickBanner', {
        'app_id': appId,
        'current_activity': currentActivity,
        'current_action': currentAction,
        'ext': ext
      });
      return result == 1;
    }
    throw MessLogV2TRackingV2Exception(
        "Method sendLogClickBanner not support platform!");
  }

  /// Invoke method channel sendLogTrackingViewParamLog native
  Future<bool> sendLogTrackingViewParamLog(ParamsLog paramsLog) async {

    String cov;
    String ltype;
    switch (paramsLog.ltype) {
      case LOG_TYPE.NONE:
        ltype = "0";
        break;
      case LOG_TYPE.PAGE_VIEW:
        ltype = "1";
        break;
      case LOG_TYPE.RECV:
        ltype = "2";
        break;
      case LOG_TYPE.BOX_VIEW:
        ltype = "3";
        break;
    }

    switch (paramsLog.cov) {
      case COV_TYPE.VIEW:
        cov = "0";
        break;
      case COV_TYPE.CLICK:
        cov = "1";
        break;
      case COV_TYPE.SCROLL:
        cov = "2";
        break;
    }

    if (Platform.isAndroid) {
      return await channel.invokeMethod('sendLogTrackingView', {
        'domain': paramsLog.domain,
        'curl': paramsLog.curl,
        'rurl': paramsLog.rurl,
        'vid': paramsLog.vid,
        'cov': cov,
        'ltype': ltype,
        'boxid': paramsLog.boxid,
        'algid': paramsLog.algid,
        'ext': paramsLog.ext
      });
    } else if (Platform.isIOS) {
       var result = await channel.invokeMethod('sendLogTrackingView', {
        'domain': paramsLog.domain,
        'curl': paramsLog.curl,
        'rurl': paramsLog.rurl,
        'vid': paramsLog.vid,
        'cov': cov,
        'ltype': ltype,
        'boxid': paramsLog.boxid,
        'algid': paramsLog.algid,
        'ext': paramsLog.ext
      });
      return result == 1;
    }

    throw MessLogV2TRackingV2Exception("sendLogTrackingView not support platform !");
  }
}
